@@ -13,16 +13,18 @@ permcor <- function(x, R = 999) {
   n <- nrow(x)
   r <- cor(x)[2]
   test <- 0.5 * log( (1 + r)/(1 - r) )  ## the test statistic
-  x2 <- x[, 2]
-  m1 <- mean(x[, 1])    ;   m12 <- sum(x[, 1]^2)
-  m2 <- mean(x2)        ;   m22 <- sum(x2^2)
-  
+  x1 <- x[, 1]      ;     x2 <- x[, 2]
+  m1 <- sum(x1)     ;     m12 <- sum(x1^2)
+  m2 <- sum(x2)     ;     m22 <- sum(x2^2)
+  up <-  m1 * m2 / n
+  down <- sqrt( (m12 - m1^2 / n) * (m22 - m2^2 / n) )
+
   sxy <- numeric(R)
   for (i in 1:R) {
-    x1 <- sample(x[ , 1], n)
-    sxy[i] <- sum(x1 * x2)
+    y1 <- sample(x1, n)
+    sxy[i] <- sum(y1 * x2)
   }  
-    rb <- (sxy - n * m1 * m2) / sqrt( (m12 - n * m1^2) * (m22 - n * m2^2) )
+    rb <- (sxy - up) / down
     tb <- 0.5 * log( (1 + rb)/(1 - rb) )  ## the test statistic
 
   pvalue <- ( sum( abs(tb) > abs(test) ) + 1 ) / (R + 1)  ## bootstrap p-value
@@ -30,5 +32,3 @@ permcor <- function(x, R = 999) {
   names(res) <- c('correlation', 'p-value')
   res
 }
-
-
